import React, { useState, useCallback, useEffect } from 'react';
import { Modal, Spin, Tabs, notification, message, Checkbox } from 'antd';
import {
  setUserRelation,
  setUserRelations
} from '@/services/userCenter/userManage/api';
import ListCardItem from '../../orgnazation/listCardItem';
const CheckboxGroup = Checkbox.Group;

const RelateRoleModal = props => {
  const {
    currentUser,
    currentSelectOrg,
    userIDs,
    visible,
    rolelist,
    stationlist,
    multiRelateRoles,
    onCancel,
    onSelect,
    loading,
    multiRoleList,
    multistationList,
    mult
  } = props;
  const { TabPane } = Tabs;
  const [roleValueList, setRoleValueList] = useState({}); // 勾选的角色列表
  const [stationValueList, setStationValueList] = useState({}); // 勾选的站点列表

  const getRoleValueCallback = useCallback((value, index) => {
    roleValueList[index] = value;
    setRoleValueList({ ...roleValueList });
  }, []);

  const getStationValueCallback = useCallback((value, index) => {
    stationValueList[index] = value;
    setStationValueList({ ...stationValueList });
  }, []);

  useEffect(() => {
    console.log(rolelist)
    console.log(stationlist)
  }, [])

  // 提交-关联角色
  const submitRole = () => {
    setUserRelation(
      currentUser.userID,
      Object.keys(roleValueList)
        .map(k => roleValueList[k])
        .flat(),
      Object.keys(stationValueList)
        .map(k => stationValueList[k])
        .flat(),
    )
      .then(res => {
        if (res.success) {
          onCancel();
          // 跳转到新组织机构下的用户表
          if (currentSelectOrg !== '-1') {
            onSelect([currentSelectOrg]);
          }
          notification.success({
            message: '提交成功',
            duration: 2,
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };
  // 提交-批量关联角色
  const submitRoles = () => {
    setUserRelations(
      userIDs,
      Object.keys(roleValueList)
        .map(k => roleValueList[k])
        .flat()
        .toString(),
      Object.keys(stationValueList)
        .map(k => stationValueList[k])
        .flat()
        .toString(),
    )
      .then(res => {
        if (res.code === 0) {
          onCancel();
          // 跳转到组织重新请求该机构下用户数据,查找用户时currentSelectOrg为'-1'，不需要重新请求
          if (currentSelectOrg !== '-1') {
            onSelect([currentSelectOrg]);
          }
          notification.success({
            message: '提交成功',
            duration: 2,
          });
        } else {
          console.log(1),
            notification.error({
              message: '提交失败',
              description: res.msg,
            });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };
  const title = (
    <span>
      <span style={{ marginRight: '20px' }}>批量关联角色</span>
      <span style={{ color: 'red' }}>提示：批量关联角色会覆盖原有角色</span>
    </span>
  );
  const title1 = (
    <span>
      <span>关联角色{currentUser.loginName}</span>
    </span>
  );
  if (mult == 'Yes') {
    return (
      <Modal
        title={multiRelateRoles ? title : title1}
        visible={visible}
        onOk={multiRelateRoles ? submitRoles : submitRole}
        onCancel={onCancel}
        okText="确认"
        cancelText="取消"
        width="500px"
      >
        <Spin spinning={loading} tip="loading">
          <Tabs defaultActiveKey="1" style={{ marginTop: '-16px' }}>
            <TabPane tab="角色" key="1">
              {visible &&
              
                rolelist.map((role, index) => {
                  return <div className={styles.cardItemData} key={index}>
                    <Divider orientation="left" style={{ margin: '0 0 10px 0', color: '#15428b', borderTopColor: '#99bbe8' }}><Checkbox indeterminate={indeterminate[index]} onChange={onCheckAllChange} index={index} checkvalue={filed[item]} checked={checkAll[index]} style={{ marginRight: '7px' }}></Checkbox>{role.visibleTitle}</Divider>
                    <CheckboxGroup options={role.roleList} value={multiRoleList} onChange={(e) => onChangeList(e, index, item)} />
                  </div>
                })}
            </TabPane>
            <TabPane tab="站点" key="2">
              {visible &&
                stationlist.map((station, index) => {
                  return <div className={styles.cardItemData} key={index}>
                    <Divider orientation="left" style={{ margin: '0 0 10px 0', color: '#15428b', borderTopColor: '#99bbe8' }}><Checkbox indeterminate={indeterminate[index]} onChange={onCheckAllChange} index={index} checkvalue={filed[item]} checked={checkAll[index]} style={{ marginRight: '7px' }}></Checkbox>{station.visibleTitle}</Divider>
                    <CheckboxGroup options={station.roleList} value={multistationList} onChange={(e) => onChangeList(e, index, item)} />
                  </div>
                })}
            </TabPane>
          </Tabs>
        </Spin>
      </Modal>
    );
  } else {
    return (
      <Modal
        title={multiRelateRoles ? title : title1}
        visible={visible}
        onOk={multiRelateRoles ? submitRoles : submitRole}
        onCancel={onCancel}
        okText="确认"
        cancelText="取消"
        width="500px"
      >
        <Spin spinning={loading} tip="loading">
          <Tabs defaultActiveKey="1" style={{ marginTop: '-16px' }}>
            <TabPane tab="角色" key="1">
              {visible &&
                rolelist.map((role, index) => (
                  <ListCardItem
                    itemid={index}
                    key={`item${index}key`}
                    userList={role.roleList}
                    multiRoleList={multiRoleList}
                    mult={mult}
                    OUName={role.visibleTitle}
                    getValueCallback={getRoleValueCallback}
                  />
                ))}
            </TabPane>
            <TabPane tab="站点" key="2">
              {visible &&
                stationlist.map((station, index) => (
                  <ListCardItem
                    itemid={index}
                    key={`item${index}key`}
                    userList={station.stationList}
                    multistationList={multistationList}
                    mult={mult}
                    OUName={station.visibleTitle}
                    getValueCallback={getStationValueCallback}
                  />
                ))}
            </TabPane>
          </Tabs>
        </Spin>
      </Modal>
    );
  }
};

export default RelateRoleModal;
